@@ -1,14 +1,15 @@
 {-# LANGUAGE CPP #-}
-#ifndef MIN_VERSION_comonad
-#define MIN_VERSION_comonad(x,y,z) 1
-#endif
 
 #if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 702
+#ifdef MIN_VERSION_comonad
 #if __GLASGOW_HASKELL__ >= 707 && (MIN_VERSION_comonad(3,0,3))
 {-# LANGUAGE Safe #-}
 #else
 {-# LANGUAGE Trustworthy #-}
 #endif
+#else
+{-# LANGUAGE Trustworthy #-}
+#endif
 #endif
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 -----------------------------------------------------------------------------
@@ -51,12 +52,10 @@ module Data.Functor.Bind (
 import Control.Applicative
 import Control.Arrow
 import Control.Category
-import Control.Comonad
-import Control.Comonad.Trans.Env
-import Control.Comonad.Trans.Store
-import Control.Comonad.Trans.Traced
 import Control.Monad (ap)
-import Control.Monad.Instances
+#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ < 707
+import Control.Monad.Instances ()
+#endif
 import Control.Monad.Trans.Cont
 import Control.Monad.Trans.Error
 import Control.Monad.Trans.Identity
@@ -73,15 +72,29 @@ import Data.Functor.Compose
 import Data.Functor.Identity
 import Data.Functor.Product
 import Data.Functor.Extend
+import Data.List.NonEmpty
+import Data.Semigroup hiding (Product)
+import Prelude hiding (id, (.))
+
+
+#ifdef MIN_VERSION_containers
 import qualified Data.IntMap as IntMap
 import Data.IntMap (IntMap)
 import qualified Data.Map as Map
 import Data.Map (Map)
-import Data.List.NonEmpty
-import Data.Semigroup hiding (Product)
 import Data.Sequence (Seq)
 import Data.Tree (Tree)
-import Prelude hiding (id, (.))
+#endif
+
+#ifdef MIN_VERSION_comonad
+import Control.Comonad
+import Control.Comonad.Trans.Env
+import Control.Comonad.Trans.Store
+import Control.Comonad.Trans.Traced
+#else
+($>) :: Functor f => f a -> b -> f b
+($>) = flip (<$)
+#endif
 
 infixl 1 >>-
 infixr 1 -<<
@@ -184,6 +197,7 @@ instance Arrow a => Apply (WrappedArrow a b) where
   (<. ) = (<* )
   ( .>) = ( *>)
 
+#ifdef MIN_VERSION_containers
 -- | A Map is not 'Applicative', but it is an instance of 'Apply'
 instance Ord k => Apply (Map k) where
   (<.>) = Map.intersectionWith id
@@ -203,6 +217,7 @@ instance Apply Tree where
   (<.>) = (<*>)
   (<. ) = (<* )
   ( .>) = ( *>)
+#endif
 
 -- MaybeT is _not_ the same as Compose f Maybe
 instance (Bind m, Monad m) => Apply (MaybeT m) where
@@ -242,6 +257,7 @@ instance (Bind m, Semigroup w) => Apply (Lazy.RWST r w s m) where
 instance Apply (ContT r m) where
   ContT f <.> ContT v = ContT $ \k -> f $ \g -> v (k . g)
 
+#ifdef MIN_VERSION_comonad
 instance (Semigroup e, Apply w) => Apply (EnvT e w) where
   EnvT ef wf <.> EnvT ea wa = EnvT (ef <> ea) (wf <.> wa)
 
@@ -250,6 +266,7 @@ instance (Apply w, Semigroup s) => Apply (StoreT s w) where
 
 instance Apply w => Apply (TracedT m w) where
   TracedT wf <.> TracedT wa = TracedT (ap <$> wf <.> wa)
+#endif
 
 -- | Wrap an 'Applicative' to be used as a member of 'Apply'
 newtype WrappedApplicative f a = WrapApplicative { unwrapApplicative :: f a }
@@ -318,6 +335,7 @@ instance Extend f => Extend (MaybeApply f) where
   duplicated w@(MaybeApply Right{}) = MaybeApply (Right w)
   duplicated (MaybeApply (Left fa)) = MaybeApply (Left (extended (MaybeApply . Left) fa))
 
+#ifdef MIN_VERSION_comonad
 instance Comonad f => Comonad (MaybeApply f) where
   duplicate w@(MaybeApply Right{}) = MaybeApply (Right w)
   duplicate (MaybeApply (Left fa)) = MaybeApply (Left (extend (MaybeApply . Left) fa))
@@ -326,6 +344,7 @@ instance Comonad f => Comonad (MaybeApply f) where
 
 instance Apply (Cokleisli w a) where
   Cokleisli f <.> Cokleisli a = Cokleisli (\w -> (f w) (a w))
+#endif
 
 -- | A 'Monad' sans 'return'.
 --
@@ -469,6 +488,7 @@ instance ArrowApply a => Bind (WrappedArrow a b) where
   (>>-) = (>>=)
 -}
 
+#ifdef MIN_VERSION_containers
 -- | A 'Map' is not a 'Monad', but it is an instance of 'Bind'
 instance Ord k => Bind (Map k) where
   m >>- f = Map.mapMaybeWithKey (\k -> Map.lookup k . f) m
@@ -482,3 +502,4 @@ instance Bind Seq where
 
 instance Bind Tree where
   (>>-) = (>>=)
+#endif
