@@ -21,18 +21,25 @@ module Data.Functor.Extend
 
 import Prelude hiding (id, (.))
 import Control.Category
-import Control.Comonad.Trans.Env
-import Control.Comonad.Trans.Store
-import Control.Comonad.Trans.Traced
 import Control.Monad.Trans.Identity
-import Data.Functor.Coproduct
 import Data.Functor.Identity
 import Data.Semigroup
 import Data.List (tails)
 import Data.List.NonEmpty (NonEmpty(..), toList)
+
+#ifdef MIN_VERSION_containers
 import Data.Sequence (Seq)
 import qualified Data.Sequence as Seq
 import Data.Tree
+#endif
+
+
+#ifdef MIN_VERSION_comonad
+import Data.Functor.Coproduct
+import Control.Comonad.Trans.Env
+import Control.Comonad.Trans.Store
+import Control.Comonad.Trans.Traced
+#endif
 
 class Functor w => Extend w where
   -- |
@@ -74,12 +81,15 @@ instance Extend ((,)e) where
 instance Semigroup m => Extend ((->)m) where
   duplicated f m = f . (<>) m
 
+#ifdef MIN_VERSION_containers
 instance Extend Seq where
   duplicated l = Seq.take (Seq.length l) (Seq.tails l)
 
 instance Extend Tree where
   duplicated w@(Node _ as) = Node w (map duplicated as)
+#endif
 
+#ifdef MIN_VERSION_comonad
 instance (Extend f, Extend g) => Extend (Coproduct f g) where
   extended f = Coproduct . coproduct
     (Left . extended (f . Coproduct . Left))
@@ -94,6 +104,7 @@ instance Extend w => Extend (StoreT s w) where
 
 instance (Extend w, Semigroup m) => Extend (TracedT m w) where
   extended f = TracedT . extended (\wf m -> f (TracedT (fmap (. (<>) m) wf))) . runTracedT
+#endif
 
 -- I can't fix the world
 -- instance (Monoid m, Extend n) => Extend (ReaderT m n)
@@ -120,21 +131,17 @@ instance Extend NonEmpty where
 -- $definition
 -- There are two ways to define an 'Extend' instance:
 --
--- I. Provide definitions for 'extend'
+-- I. Provide definitions for 'extended'
 -- satisfying this law:
 --
 -- > extended f . extended g = extended (f . extended g)
 --
--- II. Alternately, you may choose to provide definitions for 'duplicate'
+-- II. Alternately, you may choose to provide definitions for 'duplicated'
 -- satisfying this law:
 --
 -- > duplicated . duplicated = fmap duplicated . duplicated
 --
--- These are both equivalent to the statement that (->-) is associative
---
--- > (f ->- g) ->- h = f ->- (g ->- h)
---
--- You may of course, choose to define both 'duplicate' /and/ 'extend'.
+-- You may of course, choose to define both 'duplicated' /and/ 'extended'.
 -- In that case you must also satisfy these laws:
 --
 -- > extended f = fmap f . duplicated
